==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/unassigned/actions.php <==
<?php
//PJC 27-03-2019 Assign Phone to user, Don't change company

	require('../assets/inc/ldapConnect.php');
	$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
	$wanIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : @file_get_contents("http://ipecho.net/plain") ;
	
if ($mode === 'makemember') {
	
	$data = json_decode($_POST['myData'], true);
	$option = $address = $home = $plc = $usr_name = $usr_extn = $dialplan = $loginaccesscode = $sel = $new_sel = $stun = $company = array();	

	$STUNSTART = (isset($_REQUEST['STUNSTART'])) ? $_REQUEST['STUNSTART'] : "0";
	
	foreach ($data as $k => $v) {
		if (strpos($v['name'], 'stun[') !== false) {
			$stun[] = $v['value'];
		} else {
			${$v['name']}[] = $v['value'];	
		}
	}
	
	if (isset($company)) {
		$company = ($company === '00000000-0000-0000-0000-000000000000') ? '' : $company;
	}
	
		
	echo "<h3>Adding..</h3><br/>";
  	foreach ($option as $dk => $dv) {
	// Home IP Address
		$sr = ldap_search($ds,"cn=Modules","(&(objectclass=*)(guid=$home[$dk]))"); $info = ldap_get_entries($ds,$sr); $homeip = $info[0]['ipaddress'][0];
		$opt = explode(':',$dv); $option = $opt[0]; $guid = $opt[1]; $typeofphone = $opt[2];


if ($option >= "1") {
	$countW = 0;
	if ($typeofphone === '3') {
			

		//check if W and if exisits.
		if (substr($pnp_model[$dk], 0, 1) === 'W') {
			$sr = ldap_search($ds,"cn=modules","(&(objectclass=GenericIPPhone)(serialnumber=$address[$dk]))", array('cn')); 
			$info = ldap_get_entries($ds,$sr); $countW = $info['count'];
		}
		
		if ($countW < 1 ) {
			$sr = ldap_search($ds, "cn=unassignedphones" ,"(&(objectclass=unassignedphone)(serialnumber=$address[$dk]))", array('pnpvendor','pnpmodel','pnpversion'));
			$info = ldap_get_entries($ds,$sr); 
			
			$pnpvendor = $info[0]['pnpvendor'][0];
			$pnpmodel = $info[0]['pnpmodel'][0];
			$pnpversion = $info[0]['pnpversion'][0];
		}
	}
	if ($countW < 1 ) {
	// Delete unassigned
		$dn = "serialnumber=$address[$dk], cn=unassignedphones";
		ldap_delete($ds, "$dn");

	// Create Phone Object
		$typesofPhones = array('','Splicecom Analogue Port','Proactive Communication Station','Generic SIP Device');
		$att=array('objectclass'=>'Phone','typeOfPhone'=>$typeofphone,'description'=>$typesofPhones[$typeofphone],'location'=>$home[$dk]);
		$dn = ($typeofphone === '2') ? "cn=PCS $address[$dk],cn=$home[$dk], cn=modules" : "cn=SIP $address[$dk],cn=$home[$dk], cn=modules";
		ldap_add($ds, "$dn",$att);

	// Add cn=1 to phone object
	if ($typeofphone === '2') {
		$att=array('objectclass'=>'SplicePhone','serialnumber'=>$address[$dk],'partnerlogincode'=>$plc[$dk], 'pnpmodel'=>$pnp_model[$dk]);
		$dn = "cn=1,cn=PCS $address[$dk],cn=$home[$dk], cn=modules";
	} else {
		
		$att=array('objectclass'=>'GenericIPPhone','serialnumber'=>$address[$dk],'pnpvendor'=>$pnpvendor,'pnpmodel'=>$pnpmodel,'pnpversion'=>$pnpversion);
		if ($stun[$dk] === '1'){
			$att['usestun'] = $stun[$dk];
			$att['stunaddr'] = $wanIP;
			$att['stunport'] = '5060';
		}
			$att['siplicense'] ='1';
		$dn = "cn=1,cn=SIP $address[$dk],cn=$home[$dk], cn=modules";
	}
		ldap_add($ds, "$dn",$att);
	} // countW
	
	//find address GUID.
		$cn = ($typeofphone === '2') ? "PCS $address[$dk]" : "SIP $address[$dk]";
	    $sr = ldap_read($ds,"cn=$cn, cn=$home[$dk],cn=modules","objectclass=Phone"); $info = ldap_get_entries($ds,$sr);
	    $guid = $info[0]['guid'][0];

if ($option == "2") {
	// create user
		$newuser = array('objectclass'=>'user','noanswertime'=>'20','loginidletime'=>'18000','description'=>'Users Description','loginaccesscode'=>$loginaccesscode[$dk], 'company'=>$company,
			'telephonenumber'=>$usr_extn[$dk],'initialphone'=>$guid,'dialplan'=>$dialplan[$dk],'homepage'=>"http://{$homeip}/index.php?u=%u&e=%e&p=%p",'currenthome'=>$home[$dk], 'remoteworkingcode'=>$plc[$dk]);
		ldap_add($ds,"cn=$usr_name[$dk],cn=users",$newuser); unset($newuser);

	// find userguid
		$sr = ldap_list($ds,"cn=users","(&(objectclass=user)(telephonenumber=$usr_extn[$dk]))"); $info = ldap_get_entries($ds,$sr);
	    $userguid = $info[0]['guid'][0];
		}

if ($option == "3") {
	// find user dn and GUID
		$sr = ldap_list($ds,"cn=users","(&(objectclass=user)(telephonenumber=$sel[$dk]))"); $info = ldap_get_entries($ds,$sr);
	    $dn = $info[0]['dn']; $userguid = $info[0]['guid'][0]; $usercn = $info[0]['cn'][0]; $company = $info[0]['company'][0];
  
		$newuser = array('initialphone'=>$guid,'remoteworkingcode'=>$plc[$dk],'currenthome'=>$home[$dk],'company'=>$company);
		ldap_modify($ds,$dn,$newuser); unset($newuser);
		}		

	$phone = ($typeofphone === '2') ? 'PCS ' : '';
  	if ($option=="1") {
		echo "Device Added: <b>$phone$address[$dk]</b><br/>";
			audit ("[Unassigned] [Device] $phone$address[$dk]");
			} else if ($option == "3") {
		echo "Device Added: <b>$phone$address[$dk]</b> User Updated: <b>$usercn</b> / Extension Number: <b>$new_sel[$dk]</b><br/>";
			audit ("[Unassigned] [Device & User Update] $phone$address[$dk] / $usercn / $new_sel[$dk]");
			} else {
		echo "Device Added: <b>$phone$address[$dk]</b> User Created: <b>$usr_name[$dk]</b> / Extension Number: <b>$usr_extn[$dk]</b><br/>";
			audit ("[Unassigned] [Device & Create User] $phone$address[$dk] / $usr_name[$dk] / $usr_extn[$dk]");
		}
		unset($userguid,$usercn);

		} // option1 
	} // loop
	
	
	$countStun = count(array_keys($stun, 1));
	$sr=ldap_read($ds,"cn=Self,cn=Modules","objectclass=*");
	$info=ldap_get_entries($ds,$sr); $self = $info[0]['location'][0];	
	
	if ($countStun > 0 && $STUNSTART == 1) {
		ldap_modify($ds,"cn=1,guid=$self,cn=Modules",array('dontvalidateipaddress' => '1'));

		
		$publicIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : NULL;
		if ($publicIP) {
			ldap_modify($ds,"cn=1,guid=$self,cn=Modules",array('publicipaddress' => $publicIP));
		} else {
			echo "<br><b>Warning</b> Unable to set Public IP Address on SoftPBX Module<br>";
		}
		
		echo "<br><div id='restartMsg'><input type='submit' name='restart' id='restart' value='Restart SoftPBX'></div><br>";
		
	}


	
} // make member


if ($mode === 'deleteunassigned') {
	$address = (isset($_REQUEST['address']) && strlen($_REQUEST['address']) >=1 ) ? $_REQUEST['address'] : NULL;

	if ($address) {
		$unassigned = strtolower($address);
		$delete = (strpos($unassigned, '00-07-d9') !== false) ? "$unassigned" : $unassigned;
		$dn = "serialnumber=$delete, cn=unassignedphones";
        ldap_delete($ds, "$dn");
	}
}

if ($mode === 'restartModule') {
		$sr = ldap_read($ds,"cn=System","objectclass=system",array('diagnosticengineeringpassword')); 
		$info = ldap_get_entries($ds,$sr);
		$password = $info[0]['diagnosticengineeringpassword'][0];
	  
		$cmd = "echo $password | sudo -S systemctl restart adminmodule";
		system($cmd,$rv);
		echo($rv);
}

if ($mode === 'stunCheck') {
	$sr=ldap_read($ds,"cn=Self,cn=Modules","objectclass=*");
	$info=ldap_get_entries($ds,$sr); $self = $info[0]['location'][0];	
	
	$sr=ldap_read($ds,"cn=1, guid=$self,cn=Modules","objectclass=*"); $info=ldap_get_entries($ds,$sr); 
	$dontvalidateipaddress = $info[0]['dontvalidateipaddress'][0];	
	$publicipaddress = $info[0]['publicipaddress'][0];	
	echo "$dontvalidateipaddress:$publicipaddress";
}

if ($mode === 'SIPlicenceCount') {
	$qty = $used = '';
		
		$sr = ldap_list($ds,"cn=system","(&(objectclass=licenserecord)(license=_SIPPhone))",array('qty','used')); 
		$info = ldap_get_entries($ds,$sr);
		for ($m=0; $m<$info['count']; $m++) {				
			$qty = $info[$m]['qty'][0];
			$used = $info[$m]['used'][0];
		}
	
	echo trim($qty - $used);
}

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/unassigned/actions.php <==
<?php
//PJC 31-10-2019 Update wanIP and only check when STUN is used.
//PJC 27-03-2019 Assign Phone to user, Don't change company

	require('../assets/inc/ldapConnect.php');
	$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
	$timestamp = (isset($_REQUEST['timestamp']) && strlen($_REQUEST['timestamp']) >=1 ) ? $_REQUEST['timestamp'] : NULL;
	

	
if ($mode === 'makemember') {
	
	$data = json_decode($_POST['myData'], true);
	$option = $address = $home = $plc = $usr_name = $usr_extn = $dialplan = $loginaccesscode = $sel = $new_sel = $stun = $company = array();	

	$STUNSTART = (isset($_REQUEST['STUNSTART'])) ? $_REQUEST['STUNSTART'] : "0";
	
	foreach ($data as $k => $v) {
		if (strpos($v['name'], 'stun[') !== false) {
			$stun[] = $v['value'];
		} else {
			${$v['name']}[] = $v['value'];	
		}
	}
	
	if (isset($company)) {
		$company = ($company === '00000000-0000-0000-0000-000000000000') ? '' : $company;
	}
	
		
	echo "<h3>Adding..</h3><br/>";
  	foreach ($option as $dk => $dv) {
	// Home IP Address
		$sr = ldap_search($ds,"cn=Modules","(&(objectclass=*)(guid=$home[$dk]))"); $info = ldap_get_entries($ds,$sr); $homeip = $info[0]['ipaddress'][0];
		$opt = explode(':',$dv); $option = $opt[0]; $guid = $opt[1]; $typeofphone = $opt[2];


if ($option >= "1") {
	$countW = 0;
	if ($typeofphone === '3') {
			

		//check if W and if exisits.
		if (substr($pnp_model[$dk], 0, 1) === 'W') {
			$sr = ldap_search($ds,"cn=modules","(&(objectclass=GenericIPPhone)(serialnumber=$address[$dk]))", array('cn')); 
			$info = ldap_get_entries($ds,$sr); $countW = $info['count'];
		}
		
		if ($countW < 1 ) {
			$sr = ldap_search($ds, "cn=unassignedphones" ,"(&(objectclass=unassignedphone)(serialnumber=$address[$dk]))", array('pnpvendor','pnpmodel','pnpversion'));
			$info = ldap_get_entries($ds,$sr); 
			
			$pnpvendor = $info[0]['pnpvendor'][0];
			$pnpmodel = $info[0]['pnpmodel'][0];
			$pnpversion = $info[0]['pnpversion'][0];
		}
	}
	if ($countW < 1 ) {
	// Delete unassigned
		$dn = "serialnumber=$address[$dk], cn=unassignedphones";
		ldap_delete($ds, "$dn");

	// Create Phone Object
		$typesofPhones = array('','Splicecom Analogue Port','Proactive Communication Station','Generic SIP Device');
		$att=array('objectclass'=>'Phone','typeOfPhone'=>$typeofphone,'description'=>$typesofPhones[$typeofphone],'location'=>$home[$dk]);
		$dn = ($typeofphone === '2') ? "cn=PCS $address[$dk],cn=$home[$dk], cn=modules" : "cn=SIP $address[$dk],cn=$home[$dk], cn=modules";
		ldap_add($ds, "$dn",$att);

	// Add cn=1 to phone object
	if ($typeofphone === '2') {
		$att=array('objectclass'=>'SplicePhone','serialnumber'=>$address[$dk],'partnerlogincode'=>$plc[$dk], 'pnpmodel'=>$pnp_model[$dk]);
		$dn = "cn=1,cn=PCS $address[$dk],cn=$home[$dk], cn=modules";
	} else {
		
		$att=array('objectclass'=>'GenericIPPhone','serialnumber'=>$address[$dk],'pnpvendor'=>$pnpvendor,'pnpmodel'=>$pnpmodel,'pnpversion'=>$pnpversion);
		if ($stun[$dk] === '1'){
			$wanIP = (@file_get_contents("https://api.ipify.org")) ? @file_get_contents("https://api.ipify.org") : @file_get_contents("http://ipecho.net/plain");
			$att['usestun'] = $stun[$dk];
			$att['stunaddr'] = $wanIP;
			$att['stunport'] = '5060';
		}
			$att['siplicense'] ='1';
		$dn = "cn=1,cn=SIP $address[$dk],cn=$home[$dk], cn=modules";
	}
		ldap_add($ds, "$dn",$att);
	} // countW
	
	//find address GUID.
		$cn = ($typeofphone === '2') ? "PCS $address[$dk]" : "SIP $address[$dk]";
	    $sr = ldap_read($ds,"cn=$cn, cn=$home[$dk],cn=modules","objectclass=Phone"); $info = ldap_get_entries($ds,$sr);
	    $guid = $info[0]['guid'][0];

if ($option == "2") {
	// create user
		$newuser = array('objectclass'=>'user','noanswertime'=>'20','loginidletime'=>'18000','description'=>'Users Description','loginaccesscode'=>$loginaccesscode[$dk], 'company'=>$company,
			'telephonenumber'=>$usr_extn[$dk],'initialphone'=>$guid,'dialplan'=>$dialplan[$dk],'homepage'=>"http://{$homeip}/index.php?u=%u&e=%e&p=%p",'currenthome'=>$home[$dk], 'remoteworkingcode'=>$plc[$dk]);
		ldap_add($ds,"cn=$usr_name[$dk],cn=users",$newuser); unset($newuser);

	// find userguid
		$sr = ldap_list($ds,"cn=users","(&(objectclass=user)(telephonenumber=$usr_extn[$dk]))"); $info = ldap_get_entries($ds,$sr);
	    $userguid = $info[0]['guid'][0];
		}

if ($option == "3") {
	// find user dn and GUID
		$sr = ldap_list($ds,"cn=users","(&(objectclass=user)(telephonenumber=$sel[$dk]))"); $info = ldap_get_entries($ds,$sr);
	    $dn = $info[0]['dn']; $userguid = $info[0]['guid'][0]; $usercn = $info[0]['cn'][0]; $company = $info[0]['company'][0];
  
		$newuser = array('initialphone'=>$guid,'remoteworkingcode'=>$plc[$dk],'currenthome'=>$home[$dk],'company'=>$company);
		ldap_modify($ds,$dn,$newuser); unset($newuser);
		}		

	$phone = ($typeofphone === '2') ? 'PCS ' : '';
  	if ($option=="1") {
		echo "Device Added: <b>$phone$address[$dk]</b><br/>";
			audit ($timestamp, "[Unassigned] [Device] $phone$address[$dk]", "Added New Device $phone$address[$dk]");
			} else if ($option == "3") {
		echo "Device Added: <b>$phone$address[$dk]</b> User Updated: <b>$usercn</b> / Extension Number: <b>$new_sel[$dk]</b><br/>";
			audit ($timestamp, "[Unassigned] [Device & User Update] $phone$address[$dk] / $usercn / $new_sel[$dk]", "Added Device: $phone$address[$dk] and Assigned To User: $usercn / $new_sel[$dk]");
			} else {
		echo "Device Added: <b>$phone$address[$dk]</b> User Created: <b>$usr_name[$dk]</b> / Extension Number: <b>$usr_extn[$dk]</b><br/>";
			audit ($timestamp, "[Unassigned] [Device & Create User] $phone$address[$dk] / $usr_name[$dk] / $usr_extn[$dk]", "Added Device: $phone$address[$dk] and Created User: $usr_name[$dk] / $usr_extn[$dk]");
		}
		unset($userguid,$usercn);

		} // option1 
	} // loop
	
	
	$countStun = count(array_keys($stun, 1));
	$sr=ldap_read($ds,"cn=Self,cn=Modules","objectclass=*");
	$info=ldap_get_entries($ds,$sr); $self = $info[0]['location'][0];	
	
	if ($countStun > 0 && $STUNSTART == 1) {
		ldap_modify($ds,"cn=1,guid=$self,cn=Modules",array('dontvalidateipaddress' => '1'));

		
		//$publicIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : NULL;
		$publicIP = (@file_get_contents("https://api.ipify.org")) ? @file_get_contents("https://api.ipify.org") : @file_get_contents("http://ipecho.net/plain");
		if ($publicIP) {
			ldap_modify($ds,"cn=1,guid=$self,cn=Modules",array('publicipaddress' => $publicIP));
		} else {
			echo "<br><b>Warning</b> Unable to set Public IP Address on SoftPBX Module<br>";
		}
		
		echo "<br><div id='restartMsg'><input type='submit' name='restart' id='restart' value='Restart SoftPBX'></div><br>";
		
	}


	
} // make member


if ($mode === 'deleteunassigned') {
	$address = (isset($_REQUEST['address']) && strlen($_REQUEST['address']) >=1 ) ? $_REQUEST['address'] : NULL;

	if ($address) {
		$unassigned = strtolower($address);
		$delete = (strpos($unassigned, '00-07-d9') !== false) ? "$unassigned" : $unassigned;
		$dn = "serialnumber=$delete, cn=unassignedphones";
        ldap_delete($ds, "$dn");
		audit ($timestamp, "[Unassigned] [Delete] $delete", "Deleted Unassigned Device: $delete");			
	}
}

if ($mode === 'restartModule') {
		$sr = ldap_read($ds,"cn=System","objectclass=system",array('diagnosticengineeringpassword')); 
		$info = ldap_get_entries($ds,$sr);
		$password = $info[0]['diagnosticengineeringpassword'][0];
	  
		$ent["dobackup"] = "1";  	
		ldap_modify($ds,"cn=Commands",$ent);		
  
		//$cmd = "echo $password | sudo -S systemctl restart adminmodule";
		$cmd = "echo $password | sudo -S systemctl restart adminmodule && echo $password | sudo -S systemctl restart compressor && echo $password | sudo -S systemctl restart voicemail";
		system($cmd,$rv);
		echo($rv);
		audit ($timestamp, "[Unassigned] [Restart] Adminmoduke", "Restart Admin Module");			
}

if ($mode === 'stunCheck') {
	$sr=ldap_read($ds,"cn=Self,cn=Modules","objectclass=*");
	$info=ldap_get_entries($ds,$sr); $self = $info[0]['location'][0];	
	
	$sr=ldap_read($ds,"cn=1, guid=$self,cn=Modules","objectclass=*"); $info=ldap_get_entries($ds,$sr); 
	$dontvalidateipaddress = $info[0]['dontvalidateipaddress'][0];	
	$publicipaddress = $info[0]['publicipaddress'][0];	
	echo "$dontvalidateipaddress:$publicipaddress";
}

if ($mode === 'SIPlicenceCount') {
	$qty = $used = '';
		
		$sr = ldap_list($ds,"cn=system","(&(objectclass=licenserecord)(license=_SIPPhone))",array('qty','used')); 
		$info = ldap_get_entries($ds,$sr);
		for ($m=0; $m<$info['count']; $m++) {				
			$qty = $info[$m]['qty'][0];
			$used = $info[$m]['used'][0];
		}
	
	echo trim($qty - $used);
}
